//
//  HWCloudsdk.h
//  wssdk_noframe
//
//  Created by mhz on 14-8-5.
//  Copyright (c) 2014年 com.hanvon. All rights reserved.
//

#import <Foundation/Foundation.h>

@class UIImage;
// 回调block
typedef void (^successBlock)(id responseObject);
typedef void (^failureBlock)(NSError *error);
@interface HWCloudsdk : NSObject

#pragma mark 文本商务版类别枚举
typedef NS_ENUM(NSInteger, TABLE_LANGUAGE_TYPE) {
    TABLE_LANGUAGE_TYPE_table_text,             //文本商务版(纯文本)
    TABLE_LANGUAGE_TYPE_table_json,             //文本商务版(json)
    TABLE_LANGUAGE_TYPE_table_enhancedjs,       //文本商务版(加强版json)
    
};

#pragma mark 人脸动作指令(人脸活体验证)
typedef NS_ENUM(NSInteger, FACEINSTRUCTION) {
    FACEINSTRUCTION_faceToFront = 0,             //头部居中朝正前方
    FACEINSTRUCTION_turnLeft,                    //向左转动
    FACEINSTRUCTION_turnRight,                   //向右转动
    FACEINSTRUCTION_turnUp,                      //向上转动
    FACEINSTRUCTION_turnDown,                    //向下转动
    FACEINSTRUCTION_openMouth,                   //张嘴
    FACEINSTRUCTION_closeMouth,                  //闭嘴
    FACEINSTRUCTION_openEyes,                    //睁眼
    FACEINSTRUCTION_closeEyes,                   //闭眼
    FACEINSTRUCTION_judgeLight = 11,             //判断光线
    
};

#pragma mark 增值税发票图片类型
typedef NS_ENUM(NSInteger, VATINVOICEIMAGETYPE) {
    VATINVOICEIMAGETYPE_jpg = 1, // 纸质发票jpg格式
    VATINVOICEIMAGETYPE_png,     // 电子发票png格式
    VATINVOICEIMAGETYPE_pdf      // 电子发票pdf文件
};

#pragma mark 使用https请求
/**
 * 使用https请求，默认http
 */
- (void)useHttpsRequest;

#pragma mark 使用http请求
/**
 * 使用http请求，默认http
 */
- (void)useHttpRequest;

#pragma mark  名片识别

/**
 *  传入图片识别名片
 *
 *  @param language         语言类型 chns 简体 chnt繁体 en英文
 *  @param cardImage        图片
 *  @param cardImageData    图片二进制
 *  @param cardImage        图片路径
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */


-(void )cardLanguage:(NSString *)language
           cardImage:(UIImage *) cardImage
              apiKey:(NSString *)apiKey
        successBlock:(successBlock)successBlock
        failureBlock:(failureBlock)failureBlock;

-(void )cardLanguage:(NSString *)language
       cardImageData:(NSData *) cardImageData
              apiKey:(NSString *)apiKey
        successBlock:(successBlock)successBlock
        failureBlock:(failureBlock)failureBlock;


-(void )cardLanguage:(NSString *)language
       cardImagePath:(NSString *) cardImagePath
              apiKey:(NSString *)apiKey
        successBlock:(successBlock)successBlock
        failureBlock:(failureBlock)failureBlock;

#pragma mark  文本识别

/**
 *  传入文本图片识别
 *
 *  @param language         语言类型 chns 简体 chnt繁体 en英文
 *  @param textImage        文本图片
 *  @param textImageData    文本图片二进制
 *  @param textImagePath    文本图片路径
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */
-(void ) lang:(NSString *) language
    textImage:(UIImage *) textImage
       apiKey:(NSString *) apiKey
 successBlock:(successBlock)successBlock
 failureBlock:(failureBlock)failureBlock;

-(void ) lang:(NSString *) language
textImageData:(NSData *) textImageData
       apiKey:(NSString *) apiKey
 successBlock:(successBlock)successBlock
 failureBlock:(failureBlock)failureBlock;

-(void ) lang:(NSString *) language
textImagePath:(NSString *) textImagePath
       apiKey:(NSString *) apiKey
 successBlock:(successBlock)successBlock
 failureBlock:(failureBlock)failureBlock;



#pragma mark  单字手写识别

/**
 *  单字手写识别
 *
 *  @param type             1:手写轨迹识别 2:获取单字的联想字
 *  @param language         语言类型 chns 简体 chnt繁体 en英文
 *  @param data             当 type==1 时:单字手写数据。
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 */
- (void ) type:(NSString *) type
          lang:(NSString *) language
handSingleData:(NSString *) data
        apiKey:(NSString *) apiKey
  successBlock:(successBlock)successBlock
  failureBlock:(failureBlock)failureBlock;



#pragma mark 行手写识别

/**
 *  行手写识别
 *
 *  @param language         语言类型 chns 简体 chnt繁体 en英文
 *  @param data             当 type==1 时:单字手写数据。
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */
- (void ) lang:(NSString *) language
  handLineData:(NSString *) data
        apiKey:(NSString *) apiKey
  successBlock:(successBlock)successBlock
  failureBlock:(failureBlock)failureBlock;



#pragma mark 叠写识别

/**
 *  叠写识别
 *
 *  @param language         语言类型 chns 简体 chnt繁体 en英文
 *  @param data             行手写数据
 *  @param apiKey           服务授权 Key(iOS Key)
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */

- (void) lang:(NSString *) language
handRepeatData:(NSString *) data
       apiKey:(NSString *) apiKey
 successBlock:(successBlock)successBlock
 failureBlock:(failureBlock)failureBlock;

#pragma mark 身份证识别

/**
 *  传入身份证图片识别
 *
 *  @param idCardImage          身份证图片
 *  @param cropped              是否需要返回切边处理完的图片
 *  @param idCardImagePath      身份证图片路径
 *  @param idCardImageData      身份证图片二进制
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )idCardImage:(UIImage *)idCardImage
        needCropped:(BOOL)cropped
             apiKey:(NSString *) apiKey
       successBlock:(successBlock)successBlock
       failureBlock:(failureBlock)failureBlock;

-(void )idCardImagePath:(NSString *)idCardImagePath
            needCropped:(BOOL)cropped
                 apiKey:(NSString *) apiKey
           successBlock:(successBlock)successBlock
           failureBlock:(failureBlock)failureBlock;

-(void )idCardImageData:(NSData *)idCardImageData
            needCropped:(BOOL)cropped
                 apiKey:(NSString *) apiKey
           successBlock:(successBlock)successBlock
           failureBlock:(failureBlock)failureBlock;

#pragma mark 银行卡识别

/**
 *  传入银行卡图片识别
 *
 *  @param bankCardImage          银行卡图片
 *  @param cropped                是否需要返回切边处理完的图片
 *  @param bankCardImagePath      银行卡图片路径
 *  @param bankCardImageData      银行卡图片二进制
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )bankCardImage:(UIImage *)bankCardImage
            needCropped:(BOOL)cropped
             apiKey:(NSString *) apiKey
       successBlock:(successBlock)successBlock
       failureBlock:(failureBlock)failureBlock;

-(void )bankCardImagePath:(NSString *)bankCardImagePath
            needCropped:(BOOL)cropped
                 apiKey:(NSString *) apiKey
           successBlock:(successBlock)successBlock
           failureBlock:(failureBlock)failureBlock;

-(void )bankCardImageData:(NSData *)bankCardImageData
            needCropped:(BOOL)cropped
                 apiKey:(NSString *) apiKey
           successBlock:(successBlock)successBlock
           failureBlock:(failureBlock)failureBlock;

#pragma mark 营业执照识别

/**
 *  传入营业执照图片识别
 *
 *  @param businesslicenseImage          营业执照图片
 *  @param businesslicenseImagePath      营业执照图片路径
 *  @param businesslicenseImageData      营业执照图片二进制
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )businesslicenseImage:(UIImage *)businesslicenseImage
               apiKey:(NSString *) apiKey
         successBlock:(successBlock)successBlock
         failureBlock:(failureBlock)failureBlock;

-(void )businesslicenseImagePath:(NSString *)businesslicenseImagePath
                   apiKey:(NSString *) apiKey
             successBlock:(successBlock)successBlock
             failureBlock:(failureBlock)failureBlock;

-(void )businesslicenseImageData:(NSData *)businesslicenseImageData
                   apiKey:(NSString *) apiKey
             successBlock:(successBlock)successBlock
             failureBlock:(failureBlock)failureBlock;

#pragma mark 行驶证识别

/**
 *  传入行驶证图片识别
 *
 *  @param vehiclecardImage          行驶证图片
 *  @param cropped                   是否需要返回切边处理完的图片
 *  @param vehiclecardImagePath      行驶证图片路径
 *  @param vehiclecardImageData      行驶证图片二进制
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )vehiclecardImage:(UIImage *)vehiclecardImage
             needCropped:(BOOL)cropped
                  apiKey:(NSString *) apiKey
            successBlock:(successBlock)successBlock
            failureBlock:(failureBlock)failureBlock;

-(void )vehiclecardImagePath:(NSString *)vehiclecardImagePath
                 needCropped:(BOOL)cropped
                      apiKey:(NSString *) apiKey
                successBlock:(successBlock)successBlock
                failureBlock:(failureBlock)failureBlock;

-(void )vehiclecardImageData:(NSData *)vehiclecardImageData
                 needCropped:(BOOL)cropped
                      apiKey:(NSString *) apiKey
                successBlock:(successBlock)successBlock
                failureBlock:(failureBlock)failureBlock;

#pragma mark 驾驶证识别

/**
 *  传入驾驶证图片识别
 *
 *  @param drivercardImage          驾驶证图片
 *  @param cropped                  是否需要返回切边处理完的图片
 *  @param drivercardImagePath      驾驶证图片路径
 *  @param drivercardImageData      驾驶证图片二进制
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )drivercardImage:(UIImage *)drivercardImage
            needCropped:(BOOL)cropped
                 apiKey:(NSString *) apiKey
           successBlock:(successBlock)successBlock
           failureBlock:(failureBlock)failureBlock;

-(void )drivercardImagePath:(NSString *)drivercardImagePath
                needCropped:(BOOL)cropped
                     apiKey:(NSString *) apiKey
               successBlock:(successBlock)successBlock
               failureBlock:(failureBlock)failureBlock;

-(void )drivercardImageData:(NSData *)drivercardImageData
                needCropped:(BOOL)cropped
                     apiKey:(NSString *) apiKey
               successBlock:(successBlock)successBlock
               failureBlock:(failureBlock)failureBlock;


#pragma mark 增值税发票识别

/**
 *  传入增值税发票图片识别
 *  @param vatInvoiceImageData      增值税发票图片二进制数据
 *  @param imageType                上传图片类型 VATINVOICEIMAGETYPE枚举
    1，纸质发票的jpg图片；2，电子发票的png图片；3，电子发票的pdf图片文件(NSData)
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )vatInvoiceImageData:(NSData *)vatInvoiceImageData
                  imageType:(VATINVOICEIMAGETYPE)imageType
                     apiKey:(NSString *) apiKey
               successBlock:(successBlock)successBlock
               failureBlock:(failureBlock)failureBlock;

#pragma mark 身份证识别核验
/**
 *  传入身份证识别核验图片
 *
 *  @param idCardOcrVerifyImage          身份证识别核验图片
 *  @param idCardOcrVerifyImagePath      身份证识别核验图片路径
 *  @param idCardOcrVerifyImageData      身份证识别核验图片二进制
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )idCardOcrVerifyImage:(UIImage *)idCardOcrVerifyImage
                      apiKey:(NSString *) apiKey
                successBlock:(successBlock)successBlock
                failureBlock:(failureBlock)failureBlock;

-(void )idCardOcrVerifyImagePath:(NSString *)idCardOcrVerifyImagePath
                          apiKey:(NSString *) apiKey
                    successBlock:(successBlock)successBlock
                    failureBlock:(failureBlock)failureBlock;

-(void )idCardOcrVerifyImageData:(NSData *)idCardOcrVerifyImageData
                          apiKey:(NSString *) apiKey
                    successBlock:(successBlock)successBlock
                    failureBlock:(failureBlock)failureBlock;

#pragma mark 人脸身份证核验

/**
 *  传入核验图片人证核验
 *
 *  @param idCardImage          身份证图片
 *  @param faceImage            人脸图片
 *  @param idCardImagePath      身份证图片路径
 *  @param faceImagePath        人脸图片路径
 *  @param idCardImageData      身份证图片二进制
 *  @param faceImageData        人脸图片二进制
 *  @param apiKey               apikey
 */

-(void )faceIdCardVerifyWithIdCardImage:(UIImage *)idCardImage
                              faceImage:(UIImage *)faceImage
                                 apiKey:(NSString *) apiKey
                           successBlock:(successBlock)successBlock
                           failureBlock:(failureBlock)failureBlock;

-(void )faceIdCardVerifyWithIdCardImagePath:(NSString *)idCardImagePath
                              faceImagePath:(NSString *)faceImagePath
                                     apiKey:(NSString *) apiKey
                               successBlock:(successBlock)successBlock
                               failureBlock:(failureBlock)failureBlock;

-(void )faceIdCardVerifyWithIdCardImageData:(NSData *)idCardImageData
                              faceImageData:(NSData *)faceImageData
                                     apiKey:(NSString *) apiKey
                               successBlock:(successBlock)successBlock
                               failureBlock:(failureBlock)failureBlock;

#pragma mark 人脸身份证识别核验

/**
 *  传入核验图片人证核验
 *
 *  @param idCardImage          身份证图片
 *  @param faceImage            人脸图片
 *  @param idCardImagePath      身份证图片路径
 *  @param faceImagePath        人脸图片路径
 *  @param idCardImageData      身份证图片二进制
 *  @param faceImageData        人脸图片二进制
 *  @param apiKey               apikey
 */

-(void )faceIdCardOcrVerifyWithIdCardImage:(UIImage *)idCardImage
                              faceImage:(UIImage *)faceImage
                                 apiKey:(NSString *) apiKey
                           successBlock:(successBlock)successBlock
                           failureBlock:(failureBlock)failureBlock;

-(void )faceIdCardOcrVerifyWithIdCardImagePath:(NSString *)idCardImagePath
                              faceImagePath:(NSString *)faceImagePath
                                     apiKey:(NSString *) apiKey
                               successBlock:(successBlock)successBlock
                               failureBlock:(failureBlock)failureBlock;

-(void )faceIdCardOcrVerifyWithIdCardImageData:(NSData *)idCardImageData
                              faceImageData:(NSData *)faceImageData
                                     apiKey:(NSString *) apiKey
                               successBlock:(successBlock)successBlock
                               failureBlock:(failureBlock)failureBlock;

#pragma mark 人脸1：1比对
/**
 *  传入图片人脸1：1比对
 *
 *  @param templateImage        模板人脸图片
 *  @param targetImage          目标人脸图片
 *  @param templateImagePath      模板人脸图片路径
 *  @param targetImagePath        目标人脸图片路径
 *  @param templateImageData      模板人脸图片二进制
 *  @param targetImageData        目标人脸图片二进制
 *  @param apiKey               apikey
 *
 */

-(void )faceOneToOneComparisonWithTemplateImage:(UIImage *)templateImage
                                    targetImage:(UIImage *)targetImage
                                         apiKey:(NSString *) apiKey
                                   successBlock:(successBlock)successBlock
                                   failureBlock:(failureBlock)failureBlock;

-(void )faceOneToOneComparisonWithTemplateImagePath:(NSString *)templateImagePath
                                    targetImagePath:(NSString *)targetImagePath
                                             apiKey:(NSString *) apiKey
                                       successBlock:(successBlock)successBlock
                                       failureBlock:(failureBlock)failureBlock;

-(void )faceOneToOneComparisonWithTemplateImageData:(NSData *)templateImageData
                                    targetImageData:(NSData *)targetImageData
                                             apiKey:(NSString *) apiKey
                                       successBlock:(successBlock)successBlock
                                       failureBlock:(failureBlock)failureBlock;


#pragma mark 人脸活体验证
/**
 *  传入图片人脸活体验证
 *  @param faceImage          人脸图片
 *  @param faceImagePath      人脸图片路径
 *  @param faceImageData      人脸图片二进制
 *  @param faceInstruction    人脸动作指令(见FACEINSTRUCTION枚举)
 *  @param apiKey               apikey
 *
 */

-(void )faceVerifyWithFaceImage:(UIImage *)faceImage
                faceInstruction:(FACEINSTRUCTION)faceInstruction
                         apiKey:(NSString *) apiKey
                   successBlock:(successBlock)successBlock
                   failureBlock:(failureBlock)failureBlock;

-(void )faceVerifyWithFaceImagePath:(NSString *)faceImagePath
                    faceInstruction:(FACEINSTRUCTION)faceInstruction
                             apiKey:(NSString *) apiKey
                       successBlock:(successBlock)successBlock
                       failureBlock:(failureBlock)failureBlock;

-(void )faceVerifyWithFaceImageData:(NSData *)faceImageData
                    faceInstruction:(FACEINSTRUCTION)faceInstruction
                             apiKey:(NSString *) apiKey
                       successBlock:(successBlock)successBlock
                       failureBlock:(failureBlock)failureBlock;


#pragma mark 文本商务版识别-企业专用,全文本识别,支持表格,版式还原,文字定位及可信度

/**
 *  传入文本商务版图片识别
 *
 *  @param tableLanguageImage          文本商务版图片
 *  @param tableLanguageImagePath      文本商务版图片路径
 *  @param tableLanguageImageData      文本商务版图片二进制
 *  @param tableLanguageType           类别,见TABLE_LANGUAGE_TYPE枚举
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )tableLanguageImage:(UIImage *)tableLanguageImage
         tableLanguageType:(TABLE_LANGUAGE_TYPE)type
                 apiKey:(NSString *) apiKey
           successBlock:(successBlock)successBlock
           failureBlock:(failureBlock)failureBlock;

-(void )tableLanguageImagePath:(NSString *)tableLanguageImagePath
             tableLanguageType:(TABLE_LANGUAGE_TYPE)type
                     apiKey:(NSString *) apiKey
               successBlock:(successBlock)successBlock
               failureBlock:(failureBlock)failureBlock;

-(void )tableLanguageImageData:(NSData *)tableLanguageImageData
             tableLanguageType:(TABLE_LANGUAGE_TYPE)type
                     apiKey:(NSString *) apiKey
               successBlock:(successBlock)successBlock
               failureBlock:(failureBlock)failureBlock;

#pragma mark 人证比对

/**
 *  传入图片人证比对
 *
 *  @param idcardImage            身份证图片
 *  @param faceImage              人脸图片
 *  @param idcardImagePath        身份证图片路径
 *  @param faceImagePath          人脸图片路径
 *  @param idcardImageData        身份证图片二进制
 *  @param faceImageData          人脸图片二进制
 *  @param apiKey                 apikey
 *
 */


-(void )compareIdCardAndFaceWithIdCardImage:(UIImage *)idcardImage
                               faceImage:(UIImage *)faceImage
                                  apiKey:(NSString *) apiKey
                            successBlock:(successBlock)successBlock
                            failureBlock:(failureBlock)failureBlock;

-(void )compareIdCardAndFaceWithIdCardImagePath:(NSString *)idcardImagePath
                               faceImagePath:(NSString *)faceImagePath
                                      apiKey:(NSString *) apiKey
                                successBlock:(successBlock)successBlock
                                failureBlock:(failureBlock)failureBlock;

-(void )compareIdCardAndFaceWithIdCardImageData:(NSData *)idcardImageData
                               faceImageData:(NSData *)faceImageData
                                      apiKey:(NSString *) apiKey
                                successBlock:(successBlock)successBlock
                                failureBlock:(failureBlock)failureBlock;

#pragma mark 人证合一比对
/**
 *  传入图片人证合一比对
 *
 *  @param idcardImage            身份证图片
 *  @param faceImage              人脸图片
 *  @param idcardImagePath        身份证图片路径
 *  @param faceImagePath          人脸图片路径
 *  @param idcardImageData        身份证图片二进制
 *  @param faceImageData          人脸图片二进制
 *  @param apiKey                 apikey
 *
 */


-(void )recgIdCardCompareFaceWithIdCardImage:(UIImage *)idcardImage
                                   faceImage:(UIImage *)faceImage
                                      apiKey:(NSString *) apiKey
                                successBlock:(successBlock)successBlock
                                failureBlock:(failureBlock)failureBlock;

-(void )recgIdCardCompareFaceWithIdCardImagePath:(NSString *)idcardImagePath
                                   faceImagePath:(NSString *)faceImagePath
                                          apiKey:(NSString *) apiKey
                                    successBlock:(successBlock)successBlock
                                    failureBlock:(failureBlock)failureBlock;

-(void )recgIdCardCompareFaceWithIdCardImageData:(NSData *)idcardImageData
                                   faceImageData:(NSData *)faceImageData
                                          apiKey:(NSString *) apiKey
                                    successBlock:(successBlock)successBlock
                                    failureBlock:(failureBlock)failureBlock;

#pragma mark 人脸定位识别

/**
 *  人脸定位识别
 *
 *  @param faceImage        人脸图片
 *  @param faceImagePath    人脸图片路径
 *  @param faceImageData    人脸图片二进制
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */
-(void )faceImage:(UIImage *)faceImage
           apiKey:(NSString *)apiKey
     successBlock:(successBlock)successBlock
     failureBlock:(failureBlock)failureBlock;

-(void )faceImagePath:(NSString *)faceImagePath
               apiKey:(NSString *)apiKey
         successBlock:(successBlock)successBlock
         failureBlock:(failureBlock)failureBlock;

-(void )faceImageData:(NSData *)faceImageData
               apiKey:(NSString *)apiKey
         successBlock:(successBlock)successBlock
         failureBlock:(failureBlock)failureBlock;


#pragma mark 年龄、表情识别

/**
 *  传入人脸图片识别年龄、表情
 *
 *  @param faceImage        人脸图片
 *  @param faceImagePath    人脸图片路径
 *  @param faceImageData    人脸图片二进制
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */
-(void )theFaceImage:(UIImage *)faceImage
              apiKey:(NSString *)apiKey
        successBlock:(successBlock)successBlock
        failureBlock:(failureBlock)failureBlock;

-(void )theFaceImagePath:(NSString *)faceImagePath
                  apiKey:(NSString *)apiKey
            successBlock:(successBlock)successBlock
            failureBlock:(failureBlock)failureBlock;

-(void )theFaceImageData:(NSData *)faceImageData
                  apiKey:(NSString *)apiKey
            successBlock:(successBlock)successBlock
            failureBlock:(failureBlock)failureBlock;

#pragma mark 手写公式识别

/**
 *  手写公式识别
 *
 *  @param formulaData      公式数据
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */
-(void )formulaData:(NSString *)formulaData
             apiKey:(NSString *)apiKey
       successBlock:(successBlock)successBlock
       failureBlock:(failureBlock)failureBlock;

#pragma mark 题目识别

/**
 *  传入题目图片识别
 *
 *  @param problemImage         图片
 *  @param problemImagePath     图片路径
 *  @param problemImageData     图片二进制
 *  @param apiKey               apikey
 *  @param successBlock         成功回调
 *  @param failureBlock         失败回调
 *
 */
-(void )problemImage:(UIImage *)problemImage
              apiKey:(NSString *)apiKey
        successBlock:(successBlock)successBlock
        failureBlock:(failureBlock)failureBlock;

-(void )problemImagePath:(NSString *)problemImagePath
                  apiKey:(NSString *)apiKey
            successBlock:(successBlock)successBlock
            failureBlock:(failureBlock)failureBlock;

-(void )problemImageData:(NSData *)problemImageData
                  apiKey:(NSString *)apiKey
            successBlock:(successBlock)successBlock
            failureBlock:(failureBlock)failureBlock;


/**
 *  云数字识别
 *
 *  @param textImage        文本图片
 *  @param textImageData    文本图片二进制
 *  @param textImagePath    文本图片路径
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */
-(void )digitalImage:(UIImage *) textImage
       apiKey:(NSString *) apiKey
 successBlock:(successBlock)successBlock
 failureBlock:(failureBlock)failureBlock;

-(void )digitalImageData:(NSData *) textImageData
       apiKey:(NSString *) apiKey
 successBlock:(successBlock)successBlock
 failureBlock:(failureBlock)failureBlock;

-(void )digitalImagePath:(NSString *) textImagePath
       apiKey:(NSString *) apiKey
 successBlock:(successBlock)successBlock
 failureBlock:(failureBlock)failureBlock;

/**
 *  快递单手机号
 *
 *  @param textImage        快递单图片
 *  @param textImageData    快递单图片二进制
 *  @param textImagePath    快递单图片路径
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 *
 */
-(void )expressPhoneNumberImage:(UIImage *)expressPhoneNumberImage
              apiKey:(NSString *) apiKey
        successBlock:(successBlock)successBlock
        failureBlock:(failureBlock)failureBlock;

-(void )expressPhoneNumberImageData:(NSData *)expressPhoneNumberImageData
                  apiKey:(NSString *) apiKey
            successBlock:(successBlock)successBlock
            failureBlock:(failureBlock)failureBlock;

-(void )expressPhoneNumberImagePath:(NSString *)expressPhoneNumberImagePath
                  apiKey:(NSString *) apiKey
            successBlock:(successBlock)successBlock
            failureBlock:(failureBlock)failureBlock;



/**通用文本识别
 *  @param isText           0:只返回text;1:返回text、字符数、倾斜度等值
 *  @param textImage        通用文本图片
 *  @param textImageData    通用文本图片二进制
 *  @param textImagePath    通用文本图片路径
 *  @param apiKey           apikey
 *  @param successBlock     成功回调
 *  @param failureBlock     失败回调
 */
- (void)GenericTextOcrWithImage:(UIImage *)textImage isText:(NSString *)isText apiKey:(NSString *) apiKey successBlock:(successBlock)successBlock failureBlock:(failureBlock)failureBlock;

- (void)GenericTextOcrWithImageData:(NSData *)textImageData isText:(NSString *)isText apiKey:(NSString *) apiKey successBlock:(successBlock)successBlock failureBlock:(failureBlock)failureBlock;

- (void)GenericTextOcrWithImagePath:(NSString *)textImagePath isText:(NSString *)isText apiKey:(NSString *) apiKey successBlock:(successBlock)successBlock failureBlock:(failureBlock)failureBlock;
@end
